@@ -1,10 +1,12 @@
-#' @title Recode count variables into grouped factors
+#' @title Recode numeric variables into equal-ranged groups
 #' @name group_var
 #'
-#' @description Recode count variables into grouped factors, i.e. a variable is
-#'                cut into a smaller number of groups.
+#' @description Recode numeric variables into \emph{equal spaced} grouped factors,
+#'                i.e. a variable is cut into a smaller number of groups,
+#'                where each group has values of equal range.
 #'
 #' @seealso \itemize{
+#'            \item \code{\link{split_var}}
 #'            \item \code{\link{group_labels}}
 #'            \item \code{\link{group_str}}
 #'          }
@@ -16,16 +18,13 @@
 #'          a maximum of 30 groups (which is the ggplot-default grouping when
 #'          plotting histograms). Use \code{groupcount} to determine the amount
 #'          of groups.
-#' @param as.num Logical; if \code{TRUE} (default), the recoded variable will
+#' @param as.num Logical; if \code{TRUE}, the recoded variable will
 #'          be returned as numeric vector. If \code{FALSE}, a factor is returned.
 #' @param right.interval Logical; if \code{TRUE}, grouping starts with the lower
 #'          bound of \code{groupsize}. See 'Details'.
 #' @param groupcount Sets the maximum number of groups that are defined when auto-grouping is on
 #'          (\code{groupsize="auto"}). Default is 30. If \code{groupsize} is not set to \code{"auto"},
 #'          this argument will be ignored.
-#' @param asNumeric deprecated; use \code{as.num} instead
-#' @param rightInterval deprecated; use \code{right.interval} instead
-#' @param autoGroupCount deprecated; use \code{groupcount} instead
 #'
 #' @return A grouped variable, either as numeric or as factor (see paramter \code{as.num}).
 #'
@@ -49,6 +48,10 @@
 #'            46-50, 51-55, 56-60, 61-65 etc. \strong{Note:} This will cover
 #'            a range from 46-50 as first group, even if values from 46 to 49
 #'            are not present. See 'Examples' in \code{\link{group_labels}}.
+#'            \cr \cr
+#'            \emph{If you want to split a variable into a certain amount of equal
+#'            sized groups (instead of having groups where values have all the same
+#'            range), use the \code{\link{split_var}} function!}
 #'
 #' @examples
 #' age <- abs(round(rnorm(100, 65, 20)))
@@ -75,25 +78,7 @@ group_var <- function(var,
                       groupsize = 5,
                       as.num = TRUE,
                       right.interval = FALSE,
-                      groupcount = 30,
-                      asNumeric,
-                      rightInterval,
-                      autoGroupCount) {
-  # -----------------------------------
-  # warn, if deprecated param is used
-  # -----------------------------------
-  if (!missing(asNumeric)) {
-    warning("argument 'asNumeric' is deprecated; please use 'as.num' instead.")
-    as.num <- asNumeric
-  }
-  if (!missing(rightInterval)) {
-    warning("argument 'rightInterval' is deprecated; please use 'right.interval' instead.")
-    right.interval <- rightInterval
-  }
-  if (!missing(autoGroupCount)) {
-    warning("argument 'autoGroupCount' is deprecated; please use 'groupcount' instead.")
-    groupcount <- autoGroupCount
-  }
+                      groupcount = 30) {
   # do we have labels?
   varlab <- get_label(var)
   # group variable
@@ -169,20 +154,7 @@ group_var <- function(var,
 group_labels <- function(var,
                          groupsize = 5,
                          right.interval = FALSE,
-                         groupcount = 30,
-                         rightInterval,
-                         autoGroupCount) {
-  # -----------------------------------
-  # warn, if deprecated param is used
-  # -----------------------------------
-  if (!missing(rightInterval)) {
-    warning("argument 'rightInterval' is deprecated; please use 'right.interval' instead.")
-    right.interval <- rightInterval
-  }
-  if (!missing(autoGroupCount)) {
-    warning("argument 'autoGroupCount' is deprecated; please use 'groupcount' instead.")
-    groupcount <- autoGroupCount
-  }
+                         groupcount = 30) {
   # do we have labels?
   varlab <- get_label(var)
   # group variable
